import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:senior_authentication/src/screens/saml/saml_web_view.dart';

class SamlScreen extends StatelessWidget {
  const SamlScreen({Key? key, required this.username}) : super(key: key);

  final String username;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      backgroundColor: Colors.white,
      appBar: AppBar(
        iconTheme: const IconThemeData(color: Colors.black87),
        backgroundColor: Colors.white,
        shadowColor: Colors.transparent,
        title: const Text(
          'Validação SAML',
          style: TextStyle(color: Colors.black87),
        ),
      ),
      body: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 16.0),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const SizedBox(height: 48.0),
            _InsertSamlText(username),
            const Spacer(),
            _ContinueButton(username),
            const SizedBox(height: 56.0),
          ],
        ),
      ),
    );
  }
}

class _InsertSamlText extends StatelessWidget {
  _InsertSamlText(this.username);

  final String username;

  @override
  Widget build(BuildContext context) {
    var name = username.split('@')[0];

    return Container(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            'Olá,',
            style: GoogleFonts.inter(
                color: Colors.black87,
                fontSize: 32,
                fontWeight: FontWeight.w600),
          ),
          Text(
            '$name',
            style: GoogleFonts.inter(
                color: Colors.black87,
                fontSize: 32,
                fontWeight: FontWeight.w600),
          ),
          Text(
            '$username',
            style: GoogleFonts.inter(
                color: const Color(0xFF808080),
                fontSize: 16,
                fontWeight: FontWeight.w500),
          ),
          const SizedBox(height: 48.0),
          Text(
            'Sua empresa utiliza camadas de segurança SAML para autenticação, '
            'por isso precisamos validar sua senha e login externamente.',
            style: GoogleFonts.openSans(
                color: const Color(0xFF666666),
                fontSize: 16,
                fontWeight: FontWeight.w400),
          ),
        ],
      ),
    );
  }
}

class _ContinueButton extends StatelessWidget {
  _ContinueButton(this.username);

  final String username;

  @override
  Widget build(BuildContext context) {
    var tenantDomain = username.split('@')[1];
    return ElevatedButton(
      key: const Key('samlForm_continue_elevatedButton'),
      style: ButtonStyle(
        shape: MaterialStateProperty.all<RoundedRectangleBorder>(
            RoundedRectangleBorder(borderRadius: BorderRadius.circular(6.0))),
        backgroundColor: MaterialStateProperty.resolveWith<Color>(
            (states) => const Color(0xFF0E866A)),
      ),
      onPressed: () {
        Navigator.push(
          context,
          MaterialPageRoute(
            builder: (_) => SamlWebView(tenantDomain: tenantDomain),
          ),
        );
      },
      child: Container(
        height: 48,
        width: double.infinity,
        alignment: Alignment.center,
        child: Text(
          'Validar credenciais',
          style: GoogleFonts.inter(
              fontSize: 18.0, fontWeight: FontWeight.w700, color: Colors.white),
        ),
      ),
    );
  }
}
