import 'dart:async';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:senior_authentication/senior_authentication.dart';
import 'package:webview_flutter/webview_flutter.dart';

class SamlWebView extends StatefulWidget {
  const SamlWebView({Key? key, required this.tenantDomain}) : super(key: key);

  final String tenantDomain;

  @override
  _SamlWebViewState createState() => _SamlWebViewState();
}

class _SamlWebViewState extends State<SamlWebView> {
  final Completer<WebViewController> _controller =
      Completer<WebViewController>();

  final CookieManager cookieManager = CookieManager();
  Timer? timer;

  @override
  void initState() {
    super.initState();
    if (Platform.isAndroid) WebView.platform = SurfaceAndroidWebView();
  }

  @override
  void dispose() {
    timer?.cancel();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      appBar: AppBar(
        iconTheme: const IconThemeData(color: Colors.black87),
        backgroundColor: Colors.white,
        shadowColor: Colors.transparent,
        title: const Text(
          'Validação SAML',
          style: TextStyle(color: Colors.black87),
        ),
      ),
      body: Builder(builder: (BuildContext context) {
        return WebView(
          initialUrl: 'https://platform.senior.com.br/login/'
              '?redirectTo=https://platform.senior.com.br'
              '&tenant=${widget.tenantDomain}'
              '&check-browser-compatibility=false',
          javascriptMode: JavascriptMode.unrestricted,
          gestureNavigationEnabled: false,
          onWebViewCreated: (WebViewController webViewController) async {
            _controller.complete(webViewController);
            await webViewController.clearCache();
            await cookieManager.clearCookies();

            timer = Timer.periodic(
              const Duration(seconds: 2),
              (Timer t) => _checkForSeniorXCookies(webViewController, context),
            );
          },
          navigationDelegate: (NavigationRequest request) {
            // Blocking any navigation to prevent Senior X loads
            return request.url
                    .startsWith('https://platform.senior.com.br/senior-x/#/')
                ? NavigationDecision.prevent
                : NavigationDecision.navigate;
          },
        );
      }),
    );
  }

  void _checkForSeniorXCookies(
      WebViewController controller, BuildContext context) async {
    final cookies = await controller.evaluateJavascript('document.cookie');

    if (cookies.isEmpty) {
      return;
    }

    var result = cookies.split(';').firstWhere(
        (element) => element.contains('com.senior.token'),
        orElse: () => '');

    if (result.isNotEmpty) {
      AuthenticationRepository()
          .logInSaml(Uri.decodeFull(result.split('=')[1]));
    }
  }
}
