import 'dart:async';

import 'package:equatable/equatable.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:senior_authentication/senior_authentication.dart';
import 'package:senior_authentication/src/utils/exceptions.dart';
import './username_form_state.dart';

part 'username_event.dart';
part 'username_state.dart';

class UsernameBloc extends Bloc<UsernameEvent, UsernameState> {
  UsernameBloc({required this.authenticationRepository})
      : super(const UsernameState());

  final AuthenticationRepository authenticationRepository;

  @override
  Stream<UsernameState> mapEventToState(
    UsernameEvent event,
  ) async* {
    if (event is UsernameChanged) {
      yield state.copyWith(
          username: event.username, formState: const UsernameFormInitial());
    }

    if (event is UsernameSubmitted) {
      yield state.copyWith(formState: UsernameFormLoadInProgress());

      try {
        var domain = state.username.split('@')[1];
        var tenantLoginSettings =
            await authenticationRepository.getTenantLogInSettings(domain, null);

        yield state.copyWith(
            formState: UsernameFormLoadSuccess(
                username: state.username,
                tenantLoginSettings: tenantLoginSettings));
      } on TenantLogInSettingsIncorrect catch (err) {
        yield state.copyWith(formState: UsernameFormLoadFailure(err));
      } catch (_) {
        yield state.copyWith(
            formState:
                UsernameFormLoadFailure(Exception('Erro na autenticação')));
      }
    }
  }
}
